Predictable mixture of diagnostic e-increments
Source:R/diagnostics_combination.R
diagnostic_mixture.RdCombine diagnostics by a row-wise weighted average of e-increments. The weights must be fixed or predictable and each row must have total mass no larger than one.
Usage
diagnostic_mixture(
diagnostics,
weights = NULL,
diagnostic_name = "diagnostic_mixture",
alpha = diagnostics[[1L]]$alpha,
metadata = list()
)